CameraDetectionEvent class

Detection event from native camera stream.

Constructors

CameraDetectionEvent({required List<DetectionResult> detections, required int imageWidth, required int imageHeight, required int inferenceMs, required int deviceRotation})
const

Properties

detections List<DetectionResult>
final
deviceRotation int
Device physical rotation in degrees (0, 90, 180, 270). 0 = portrait, 90 = landscape-left, 270 = landscape-right.
final
hashCode int
The hash code for this object.
no setterinherited
imageHeight int
final
imageWidth int
final
inferenceMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited