CameraInfo class

Camera info returned by startCamera.

Constructors

CameraInfo({required int textureId, required int previewWidth, required int previewHeight})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
previewHeight int
final
previewWidth int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textureId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited