CaptureResult class

Result of a photo capture.

Constructors

CaptureResult({required String cleanPath, required String annotatedPath, required List<DetectionResult> detections})
const

Properties

annotatedPath String
Path to the annotated image (with bbox drawn).
final
cleanPath String
Path to the clean image (no bbox).
final
detections List<DetectionResult>
Detections at the moment of capture.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited