DetectionResult class

Detection result from PicoDet model.

Constructors

DetectionResult({required int label, required double probability, required double x, required double y, required double width, required double height})
const
DetectionResult.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
Bounding box height (absolute pixels).
final
label int
Class label index (0-based).
final
probability double
Confidence probability (0.0 - 1.0).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
Bounding box width (absolute pixels).
final
x double
Bounding box x coordinate (absolute pixels).
final
y double
Bounding box y coordinate (absolute pixels).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited