PaddleDetectionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • PaddleDetectionPlatform
Implementers

Constructors

PaddleDetectionPlatform()
Constructs a PaddleDetectionPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect({required String imagePath}) Future<List<DetectionResult>>
Run detection on an image file.
detectFromBytes({required Uint8List data, required int width, required int height}) Future<List<DetectionResult>>
Run detection on raw RGBA pixel bytes (e.g., from camera frame).
dispose() Future<void>
Release native resources.
getPlatformVersion() Future<String?>
loadModel({required String paramName, required String binName, int numClass = 1, int sizeId = 0, int cpuGpu = 0}) Future<bool>
Load a PicoDet model from Android assets.
loadModelFromFile({required String paramPath, required String binPath, int numClass = 1, int sizeId = 0, int cpuGpu = 0}) Future<bool>
Load a PicoDet model from absolute file paths (e.g., user-picked files).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setThreshold({double probThreshold = 0.5, double nmsThreshold = 0.45}) Future<void>
Update detection thresholds.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PaddleDetectionPlatform
The default instance of PaddleDetectionPlatform to use.
getter/setter pair